library astextfield;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

enum InputType { normal, password, number, email }

// ignore: must_be_immutable
class astextfield extends StatelessWidget {

  //TEXT FIELD HINT
  final String hint;

  //TEXT FIELD ICON PATH
  final String iconPath;

  //TEXT FIELD HINT COLOR
  Color hintColor = Colors.black;

  //TEXT FIELD BELOW LINE COLOR
  Color lineColor = Colors.black;

  //INIT TEXT FIELD
  final inputTextFieldValue;

  //INPUT TYPE FOR TEXT FIELD - NUMBER, PASSWORD, EMAIL, TEXT
  InputType textFieldInputType = InputType.normal;

  //STYLE OF TEXT
  TextStyle style = setFont();

  //FUNCTION TO VALIDATE TEXTFIELD
  FormFieldValidator<String> txtValidator;

  //CONSTRUCTOR
  astextfield(
      this.hint, this.iconPath, this.inputTextFieldValue, this.txtValidator,
      [this.hintColor, this.lineColor, this.textFieldInputType, this.style]);

  //FOR FOCUS TO TEXT FIELD
  final FocusNode focus = new FocusNode();

  @override
  Widget build(BuildContext context) {
    return new Container(
      width: MediaQuery.of(context).size.width,
      margin: const EdgeInsets.only(left: 25.0, right: 25.0),
      alignment: Alignment.center,
      child: Stack(
        children: <Widget>[
          Container(
            child: Align(
              //RIGHT SIDE BUTTON FOR CLICK AND NAVIGATE TO NEXT SCREEN
              alignment: Alignment.topLeft,
              child: Padding(
                padding: const EdgeInsets.only(top: 16),
                child: Image.asset(
                  iconPath,
                  width: 16.0,
                  height: 16.0,
                ),
              ),
            ),
          ),
          Container(
            width: MediaQuery.of(context).size.width,
            child: Align(
              //RIGHT SIDE BUTTON FOR CLICK AND NAVIGATE TO NEXT SCREEN
              alignment: Alignment.topRight,
              child: TextFormField(
                style: style,
                focusNode: focus,
                controller: inputTextFieldValue,
                textAlign: TextAlign.start,
                textAlignVertical: TextAlignVertical.center,
                //SET KEYBOARD TYPE FOR - NUMBER, TEXT, EMAIL, ETC.
                keyboardType: getKeyboardType(),
                //TEXT FIELD TYPE PASSWORD or NOT, obscureText = true MEANS PASSWORD TYPE
                obscureText:
                ((setTextFieldInputType(textFieldInputType) ==
                    TextInputType.visiblePassword)
                    ? true
                    : false),
                validator: txtValidator,
                decoration: InputDecoration(
                  contentPadding: const EdgeInsets.only(left: 25.0, bottom: 16),
                  hintText: hint,
                  hintStyle: TextStyle(color: hintColor, fontSize: 15),
                  errorStyle: TextStyle(fontSize: 15),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  //FUNCTION RETURNS TEXT FILED TO GET ALL PARAMETERS OF TEXT FILED
  TextEditingController getFieldValue() {
    return inputTextFieldValue;
  }

  getKeyboardType() {
    return setTextFieldInputType(textFieldInputType);
  }

  static setFont([FontWeight weight = FontWeight.normal,
    FontStyle style = FontStyle.normal, double fontSize = 15, String family = "Roboto"]) {
    return TextStyle(
        fontFamily: "Roboto",

        //FontWeight - normal OR bold
        fontWeight: weight,

        //FontStyle - normal OR italic
        fontStyle: style,

        //Text font size
        fontSize: fontSize);
  }

  TextInputType setTextFieldInputType(InputType type) {
    if (type == InputType.normal) {
      return TextInputType.text;
    } else if (type == InputType.password) {
      return TextInputType.visiblePassword;
    } else if (type == InputType.number) {
      return TextInputType.number;
    } else if (type == InputType.email) {
      return TextInputType.emailAddress;
    }
    return TextInputType.text;
  }
}
